==> fishsupper-0.1.3.tar.gz: fishsupper-0.1.3/src/settings.cc <==
//  Fish Supper
//  Copyright (C) 2006 Matthew Clarke <matthew_larcke@lycos.co.uk>
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
// 
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
//  02111-1307, USA.




#include "settings.h"




//extern bool joystick_available;




// *******************
// *** CONSTRUCTOR ***
// *******************
FS::Settings::Settings()
{
    // default values
    fullscreen = false;
    joystick_selected = false;
    sound = true;
    
    read_config_file();
    
    //print_settings();
    
} // FS::Settings::Settings()

// ******************
// *** DESTRUCTOR ***
// ******************
FS::Settings::~Settings()
{
    // nothing
    
} // FS::Settings::~Settings()




// ************************
// *** MEMBER FUNCTIONS ***
// ************************

// **************************************************

void FS::Settings::read_config_file()
{
    std::string my_file = fs_dir;
    my_file += "/config.txt";
    
    std::ifstream fin( my_file.c_str() );
    if ( !fin.is_open() )
    {
        std::cerr << "Can't open " << my_file << std::endl;
        exit(EXIT_FAILURE);
    } // if
    
    std::string my_line;
    while ( getline(fin, my_line) )
    {
        // split this into two, each side of '='
        int split_index = my_line.find('=');
        std::string attr = my_line.substr(0, split_index);
        int val = atoi( (my_line.substr(split_index + 1)).c_str() );
        
        if ( attr == "fullscreen" )
        {
            fullscreen = (bool) val;
        }
        else if ( (attr == "joystick_selected") && joystick_available )
        {
            // If no joysticks are available, this setting remains at 
            // default value (i.e. false).
            joystick_selected = (bool) val;
        }
        else if ( attr == "sound" )
        {
            sound = (bool) val;
        } // if ... else
    } // while
    
    fin.close();
    
} // FS::Settings::read_config_file()

// **************************************************

void FS::Settings::write_config_file(bool _joystick_selected, bool _sound, 
        bool _fullscreen) 
{
    // First, check that the given values are different from the 
    // ones we've already got. If they're the same, there's no 
    // point in writing a new config file...
    if ( _joystick_selected == joystick_selected && _sound == sound && 
         _fullscreen == fullscreen )
    {
        return;
    } // if
    
    std::string my_file = fs_dir;
    my_file += "/config.txt";
    
    std::ofstream fout( my_file.c_str() );
    if ( !fout.is_open() )
    {
        std::cerr << "Can't open " << my_file << std::endl;
        exit(EXIT_FAILURE);
    } // if
    
    joystick_selected = _joystick_selected;
    sound = _sound;
    fullscreen = _fullscreen;
    
    fout << "joystick_selected=" << ((joystick_selected) ? "1" : "0") << std::endl;
    fout << "sound=" << ((sound) ? "1" : "0") << std::endl;
    fout << "fullscreen=" << ((fullscreen) ? "1" : "0") << std::endl;
    
    fout.close();
    
} // FS::Settings::write_config_file()

// **************************************************

void FS::Settings::print_settings() const
{
    std::cout << "fullscreen=" << fullscreen << std::endl;
    std::cout << "joystick_selected=" << joystick_selected << std::endl;
    std::cout << "sound=" << sound << std::endl;
    
} // FS::Settings::print_settings()

// **************************************************
// **************************************************

==> fishsupper-0.1.4.tar.gz: fishsupper-0.1.4/src/settings.cc <==
// $Id: settings.cc,v 1.4 2006/08/05 09:08:59 matthew Exp $

//  Fish Supper
//  Copyright (C) 2006 Matthew Clarke <matthew_larcke@lycos.co.uk>
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 2
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
// 
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
//  02111-1307, USA.




#include "settings.h"




// *******************
// *** CONSTRUCTOR ***
// *******************
FS::Settings::Settings()
{
    // default values
    fullscreen = false;
    joystick_selected = false;
    sound = true;
    furthest_level = 1;
    
    read_config_file();
    
} // FS::Settings::Settings()

// ******************
// *** DESTRUCTOR ***
// ******************
FS::Settings::~Settings()
{
    // By time this gets called, fs_dir has become corrupted.
    //write_config_file();
    
} // FS::Settings::~Settings()




// ************************
// *** MEMBER FUNCTIONS ***
// ************************

// **************************************************

void FS::Settings::read_config_file()
{
    std::string my_file = fs_dir;
    my_file += "/config.txt";
    
    std::ifstream fin( my_file.c_str() );
    if ( !fin.is_open() )
    {
        std::cerr << "Can't open " << my_file << std::endl;
        exit(EXIT_FAILURE);
    } // if
    
    std::string my_line;
    while ( getline(fin, my_line) )
    {
        // split this into two, each side of '='
        int split_index = my_line.find('=');
        std::string attr = my_line.substr(0, split_index);
        int val = atoi( (my_line.substr(split_index + 1)).c_str() );
        
        if ( attr == "fullscreen" )
        {
            fullscreen = (bool) val;
        }
        else if ( (attr == "joystick_selected") && joystick_available )
        {
            // If no joysticks are available, this setting remains at 
            // default value (i.e. false).
            joystick_selected = (bool) val;
        }
        else if ( attr == "sound" )
        {
            sound = (bool) val;
        } 
        else if ( attr == "furthest_level" )
        {
            furthest_level = val;
        } // if ... else
    } // while
    
    fin.close();
    
} // FS::Settings::read_config_file()

// **************************************************
/*
void FS::Settings::write_config_file(bool _joystick_selected, bool _sound, 
        bool _fullscreen, int _furthest_level) 
{
    // First, check that the given values are different from the 
    // ones we've already got. If they're the same, there's no 
    // point in writing a new config file...
    if ( _joystick_selected == joystick_selected && _sound == sound && 
         _fullscreen == fullscreen && _furthest_level == furthest_level )
    {
        return;
    } // if
    
    std::string my_file = fs_dir;
    my_file += "/config.txt";
    
    std::ofstream fout( my_file.c_str() );
    if ( !fout.is_open() )
    {
        std::cerr << "Can't open " << my_file << std::endl;
        exit(EXIT_FAILURE);
    } // if
    
    joystick_selected = _joystick_selected;
    sound = _sound;
    fullscreen = _fullscreen;
    furthest_level = _furthest_level;
    
    fout << "joystick_selected=" << ((joystick_selected) ? "1" : "0") << std::endl;
    fout << "sound=" << ((sound) ? "1" : "0") << std::endl;
    fout << "fullscreen=" << ((fullscreen) ? "1" : "0") << std::endl;
    fout << "furthest_level=" << furthest_level << std::endl;
    
    fout.close();
    
} // FS::Settings::write_config_file()
*/
// **************************************************
        
void FS::Settings::write_config_file() 
{
    std::string my_file = fs_dir;
    my_file += "/config.txt";
    
    // FIXME: unopened file shouldn't mean app exits.
    std::ofstream fout( my_file.c_str() );
    if ( !fout.is_open() )
    {
        std::cerr << "Can't open " << my_file << std::endl;
        exit(EXIT_FAILURE);
    } // if
    
    fout << "joystick_selected=" << ((joystick_selected) ? "1" : "0") << std::endl;
    fout << "sound=" << ((sound) ? "1" : "0") << std::endl;
    fout << "fullscreen=" << ((fullscreen) ? "1" : "0") << std::endl;
    fout << "furthest_level=" << furthest_level << std::endl;
    
    fout.close();
    
} // FS::Settings::write_config_file()

// **************************************************

void FS::Settings::print_settings() const
{
    std::cout << "fullscreen=" << fullscreen << std::endl;
    std::cout << "joystick_selected=" << joystick_selected << std::endl;
    std::cout << "sound=" << sound << std::endl;
    std::cout << "furthest_level=" << furthest_level << std::endl;
    
} // FS::Settings::print_settings()

// **************************************************

void FS::Settings::set_furthest_level(int lev)
{
    if ( lev > furthest_level )
    {
        furthest_level = lev;
    } // if
    
} // FS::Settings::set_furthest_level()
 
// **************************************************
